package cn.bunny.controller;


import cn.bunny.common.spzx.model.entity.product.Brand;
import cn.bunny.common.spzx.model.vo.common.Result;
import cn.bunny.common.spzx.model.vo.common.ResultCodeEnum;
import cn.bunny.service.BrandService;
import com.github.pagehelper.PageInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "商品分类")
@RequestMapping("/admin/product/brand")
@RestController
public class BranController {

    @Autowired
    private BrandService brandService;

    @Operation(summary = "查询所有品牌", description = "查询所有品牌")
    @GetMapping("findAll")
    public Result findAll() {
      List<Brand> brandList= brandService.findAll();
        return Result.build(brandList, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "获取品牌列表", description = "获取品牌全部列表")
    @GetMapping("{page}/{limit}")
    public Result list(@PathVariable("page") Integer page, @PathVariable("limit") Integer limit) {

        PageInfo<Brand> pageInfo = brandService.findByPage(page, limit);

        return Result.build(pageInfo, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "添加品牌", description = "添加品牌")
    @PostMapping("save")
    public Result save(@RequestBody Brand brand) {
        brandService.save(brand);

        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "修改品牌", description = "修改品牌")
    @PutMapping("updateById")
    public Result updateById(@RequestBody Brand brand) {
        brandService.updateById(brand);

        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "删除品牌", description = "删除品牌")
    @DeleteMapping("deleteById/{id}")
    public Result deleteById(@PathVariable("id") Integer id) {
        brandService.deleteById(id);

        return Result.build(null, ResultCodeEnum.SUCCESS);
    }
}
