package cn.bunny.service.impl;

import cn.bunny.common.AuthContextUtil;
import cn.bunny.common.exception.BunnyException;
import cn.bunny.common.spzx.model.entity.system.SysMenu;
import cn.bunny.common.spzx.model.entity.system.SysUser;
import cn.bunny.common.spzx.model.vo.common.ResultCodeEnum;
import cn.bunny.common.spzx.model.vo.system.SysMenuVo;
import cn.bunny.mapper.SysMenuMapper;
import cn.bunny.service.SysMenuService;
import cn.bunny.utils.MenuHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.LinkedList;
import java.util.List;

@Service
public class SysMenuServiceImpl implements SysMenuService {
    @Autowired
    private SysMenuMapper sysMenuMapper;

    // 查询所有子节点
    @Override
    public List<SysMenu> findNodes() {
        List<SysMenu> sysMenuList = sysMenuMapper.findAll();
        if (CollectionUtils.isEmpty(sysMenuList)) {
            return null;
        }

        return MenuHelper.buildTree(sysMenuList);
    }

    // 添加菜单
    @Override
    public void save(SysMenu sysMenu) {
        sysMenuMapper.save(sysMenu);
    }

    // 修改菜单
    @Override
    public void update(SysMenu sysMenu) {
        sysMenuMapper.update(sysMenu);
    }

    // 删除菜单
    @Override
    public void removeById(Long id) {
        Long count = sysMenuMapper.selectById(id);
        if (count > 0) {
            throw new BunnyException(ResultCodeEnum.NODE_ERROR);
        }
        sysMenuMapper.removeById(id);
    }

    // 查询用户可以操作菜单
    @Override
    public List<SysMenuVo> findMenusByUserId() {
        // 获取当前用户id
        SysUser sysUser = AuthContextUtil.get();
        Long userId = sysUser.getId();

        // 根据userid查询可以操作菜单
        List<SysMenu> sysMenuList = sysMenuMapper.findMenuByUserId(userId);
        List<SysMenu> sysMenus = MenuHelper.buildTree(sysMenuList);

        return this.buildMenus(sysMenus);
    }


    // 将List<SysMenu>对象转换成List<SysMenuVo>对象
    private List<SysMenuVo> buildMenus(List<SysMenu> menus) {

        List<SysMenuVo> sysMenuVoList = new LinkedList<SysMenuVo>();
        for (SysMenu sysMenu : menus) {
            SysMenuVo sysMenuVo = new SysMenuVo();
            sysMenuVo.setTitle(sysMenu.getTitle());
            sysMenuVo.setName(sysMenu.getComponent());
            List<SysMenu> children = sysMenu.getChildren();
            if (!CollectionUtils.isEmpty(children)) {
                sysMenuVo.setChildren(buildMenus(children));
            }
            sysMenuVoList.add(sysMenuVo);
        }
        return sysMenuVoList;
    }
}
